﻿function TDAutoVendor(maxValue, priceSource, maxQuality, maxIlvl, sellCrapBlue, debug, disenchant, valueDiff)
    maxValue = maxValue or 5000000;
    priceSource = priceSource or 'DBGlobalSaleAvg';
    maxQuality = maxQuality or 3;
    sellCrapBlue = sellCrapBlue or true;
    debug = debug or false;
	disenchant = disenchant or false;
	valueDiff = valueDiff or 100000;
	maxIlvl = maxIlvl or 630;
    -- 0 = junk, 1 = normal, 2 = green, 3 = blue, 4 = purple, 5 = legendary

    local prof1, prof2 = GetProfessions();
	local _, _, _, _, _, _, skillLine1 = GetProfessionInfo(prof1);
	local _, _, _, _, _, _, skillLine2 = GetProfessionInfo(prof2);
    local hasEnchanting = skillLine1 == 333 or skillLine2 == 333;

    if debug then
        print('max value: ' .. maxValue .. ', source: ' .. priceSource .. ', maxQ: ' .. maxQuality .. ', sell blue: '
            .. tostring(sellCrapBlue) .. ', maxIlvl: ' .. maxIlvl .. ', has ench: ' .. tostring(hasEnchanting));
    end

    local WEAPON, ARMOR = TSMAPI.Util:Select({1, 2}, GetAuctionItemClasses());

    for bag, slot, itemString in TSMAPI.Inventory:BagIterator(nil, true) do
        local _, itemLink, quality, ilvl, _, iType, _, _, _, _, vendorPrice = TSMAPI.Item:GetInfo(itemString);
        local disenchantable = TSMAPI.Item:IsDisenchantable(itemString);
        local soulbound = TSMAPI.Item:IsSoulbound(itemString);
        local customSalePrice = TSMAPI:GetCustomPriceValue(priceSource, itemString);
		local disenchantPrice = TSMAPI:GetCustomPriceValue('Destroy', itemString);

        if itemString and vendorPrice > 0 and
            (quality == 0 or -- junk
                (disenchantable and ilvl <= maxIlvl and (iType == ARMOR or iType == WEAPON) and quality <= maxQuality) and
				(not disenchant or not (vendorPrice ~= nil and disenchantPrice ~= nil and
					(disenchantPrice - vendorPrice >= valueDiff))) and
                (
                    (customSalePrice and customSalePrice <= maxValue) or
                    (
                        not hasEnchanting and sellCrapBlue and soulbound and quality == 3 and
                        ilvl >= 570 and ilvl <= 630 and (not customSalePrice or customSalePrice <= maxValue)
                    )
                )
            )
        then
            local venPrice = '';
            local cusPrice = '';
            if vendorPrice > 0 then
                venPrice = ' V: ' .. TSMAPI:MoneyToString(vendorPrice, 'OPT_ICON');
			end
			if disenchant and disenchantPrice and disenchantPrice > 0 then
				cusPrice = ' D: ' .. TSMAPI:MoneyToString(disenchantPrice, 'OPT_ICON');
			end
            if customSalePrice and customSalePrice > 0 then
                cusPrice = cusPrice .. ' AH: ' .. TSMAPI:MoneyToString(customSalePrice, 'OPT_ICON');
			end


            if debug then
                print('Would sell ' .. itemLink .. venPrice .. cusPrice);
            elseif MerchantFrame:IsShown() then
                print('Selling ' .. itemLink .. venPrice .. cusPrice);
                ShowContainerSellCursor(bag, slot);
                UseContainerItem(bag, slot);
                ResetCursor();
            else
                print('Merchant frame is not opened!');
            end
        end
    end
end

function TDAutoDisenchant(debug, maxValue, valueDiff, priceSource, maxQuality, maxIlvl)
	maxValue = maxValue or 5000000;
	valueDiff = valueDiff or 100000;
	priceSource = priceSource or 'DBGlobalSaleAvg';
	maxQuality = maxQuality or 3;
	debug = debug or false;
	maxIlvl = maxIlvl or 630;
	-- 0 = junk, 1 = normal, 2 = green, 3 = blue, 4 = purple, 5 = legendary

	local prof1, prof2 = GetProfessions();
	if not (prof1 == 8 or prof2 == 8) then
		return;
	end

	if debug then
		print('value diff: ' .. valueDiff .. ', source: ' .. priceSource .. ', maxQ: ' .. maxQuality ..
				', maxIlvl: ' .. maxIlvl);
	end

	for bag, slot, itemString in TSMAPI.Inventory:BagIterator(nil, true) do
		local _, itemLink, quality, ilvl, _, _, _, _, _, _, vendorPrice = TSMAPI.Item:GetInfo(itemString);
		local disenchantable = TSMAPI.Item:IsDisenchantable(itemString);
		local customSalePrice = TSMAPI:GetCustomPriceValue(priceSource, itemString);
		local disenchantPrice = TSMAPI:GetCustomPriceValue('Destroy', itemString);

		if itemString and disenchantable and ilvl <= maxIlvl and quality <= maxQuality and
			(not customSalePrice or customSalePrice <= maxValue) and
			(vendorPrice ~= nil and disenchantPrice ~= nil and (disenchantPrice - vendorPrice >= valueDiff))
		then
			local venPrice = '';
			local cusPrice = '';
			if vendorPrice > 0 then
				venPrice = ' V: ' .. TSMAPI:MoneyToString(vendorPrice, 'OPT_ICON');
			end
			if disenchantPrice and disenchantPrice > 0 then
				cusPrice = ' D: ' .. TSMAPI:MoneyToString(disenchantPrice, 'OPT_ICON');
			end

			if debug then
				print('Would dis ' .. itemLink .. venPrice .. cusPrice);
			else
				print('Dissing ' .. itemLink .. venPrice .. cusPrice);
				TDDisButton:SetAttribute('macrotext', format('/cast Disenchant\n/use %d %d', bag, slot));
				return;
			end
		end
	end
end


function TDAutoOpen(debug)
	debug = debug or false;
	-- 0 = junk, 1 = normal, 2 = green, 3 = blue, 4 = purple, 5 = legendary

	for bag, slot, itemString in TSMAPI.Inventory:BagIterator(nil, true) do
		local name, itemLink, quality, ilvl, minLvl, iType = TSMAPI.Item:GetInfo(itemString);
		local soulbound = TSMAPI.Item:IsSoulbound(itemString);
		local usable = IsUsableItem(itemLink);

		local customSalePrice = TSMAPI:GetCustomPriceValue('DBGlobalSaleAvg', itemString);

		if itemString and usable and soulbound and not customSalePrice and
			(
				(minLvl >= 90 and
				(
					string.find(name, 'Tormented') or
					string.find(name, 'Formidable') or
					string.find(name, 'Baleful') or
					string.find(name, 'Grandiose') or
					string.find(name, 'Turbulent') or
					string.find(name, 'Munificent')
				)) or
				string.find(name, 'Enhancement Token') or
				string.find(name, 'Runic Pouch') or
				string.find(name, 'Cache of Highmaul Treasures') or
				string.find(name, 'Iron Fleet Treasure Chest') or
				string.find(name, 'Blackrock Foundry Spoils')
			)
		then
			if debug then
				print('Would use ' .. itemLink);
			else
				print('Using ' .. itemLink);
				TDOpenButton:SetAttribute('macrotext', format('/use %d %d', bag, slot));
				return;
			end
		end
	end
end

local TDDisFrame = CreateFrame('Frame');
TDDisFrame:RegisterEvent('PLAYER_ENTERING_WORLD')
TDDisFrame:SetScript('OnEvent', function(self, event, ...)
	TDDisButton = CreateFrame('Button', 'TDDisButton', nil, 'SecureActionButtonTemplate');
	TDDisButton:SetScript('PreClick', function()
		TDAutoDisenchant(TD_debug, TD_maxValue, TD_valueDiff, TD_priceSource, TD_maxQuality, TD_maxIlvl);
	end);
	TDDisButton:SetAttribute('type', 'macro');

	TDOpenButton = CreateFrame('Button', 'TDOpenButton', nil, 'SecureActionButtonTemplate');
	TDOpenButton:SetScript('PreClick', function()
		TDAutoOpen(TD_debug);
	end);
	TDOpenButton:SetAttribute('type', 'macro');
end)
